@@ -421,8 +421,9 @@ class BaseMetaEnum(type):
     def getTermByToken(self, token):
         """See `IVocabularyTokenized`."""
         # The sort_order of the enumerated type lists all the items.
-        if token in self.sort_order:
-            return TokenizedItem(getattr(self, token))
+        upper_token = token.upper()
+        if upper_token in self.sort_order:
+            return TokenizedItem(getattr(self, upper_token))
         else:
             # If the token is not specified in the sort order then check
             # the titles of the items.  This is to support the transition
